@@ -1,9 +1,29 @@
 /* command.h -- The structures used internally to represent commands, and
    the extern declarations of the functions used to create them. */
 
+/* Copyright (C) 1993 Free Software Foundation, Inc.
+
+   This file is part of GNU Bash, the Bourne Again SHell.
+
+   Bash is free software; you can redistribute it and/or modify it under
+   the terms of the GNU General Public License as published by the Free
+   Software Foundation; either version 2, or (at your option) any later
+   version.
+
+   Bash is distributed in the hope that it will be useful, but WITHOUT ANY
+   WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with Bash; see the file COPYING.  If not, write to the Free Software
+   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
+
 #if !defined (_COMMAND_H)
 #define _COMMAND_H
 
+#include "stdc.h"
+
 /* Instructions describing what kind of thing to do for a redirection. */
 enum r_instruction {
   r_output_direction, r_input_direction, r_inputa_direction,
@@ -14,7 +34,7 @@ enum r_instruction {
 };
 
 /* Command Types: */
-enum command_type { cm_for, cm_case, cm_while, cm_if, cm_simple,
+enum command_type { cm_for, cm_case, cm_while, cm_if, cm_simple, cm_select,
 		    cm_connection, cm_function_def, cm_until, cm_group };
 
 /* A structure which represents a word. */
@@ -42,15 +62,18 @@ typedef struct word_list {
 
 /* What a redirection descriptor looks like.  If FLAGS is IS_DESCRIPTOR,
    then we use REDIRECTEE.DEST, else we use the file specified. */
+
+typedef union {
+  long dest;			/* Place to redirect REDIRECTOR to, or ... */
+  WORD_DESC *filename;		/* filename to redirect to. */
+} REDIRECTEE;
+
 typedef struct redirect {
   struct redirect *next;	/* Next element, or NULL. */
   int redirector;		/* Descriptor to be redirected. */
   int flags;			/* Flag value for `open'. */
   enum r_instruction  instruction; /* What to do with the information. */
-  union {
-    int dest;			/* Place to redirect REDIRECTOR to, or ... */
-    WORD_DESC *filename;	/* filename to redirect to. */
-  } redirectee;
+  REDIRECTEE redirectee;	/* File descriptor or filename */
   char *here_doc_eof;		/* The word that appeared in <<foo. */
 } REDIRECT;
 
@@ -68,11 +91,13 @@ typedef struct element {
 #define CMD_IGNORE_RETURN  0x08	/* Ignore the exit value.  For set -e. */
 #define CMD_NO_FUNCTIONS   0x10 /* Ignore functions during command lookup. */
 #define CMD_INHIBIT_EXPANSION 0x20 /* Do not expand the command words. */
+#define CMD_NO_FORK	   0x40	/* Don't fork; just call execve */
 
 /* What a command looks like. */
 typedef struct command {
   enum command_type type;	/* FOR CASE WHILE IF CONNECTION or SIMPLE. */
   int flags;			/* Flags controlling execution environment. */
+  int line;			/* line number the command starts on */
   REDIRECT *redirects;		/* Special redirects for FOR CASE, etc. */
   union {
     struct for_com *For;
@@ -83,6 +108,9 @@ typedef struct command {
     struct simple_com *Simple;
     struct function_def *Function_def;
     struct group_com *Group;
+#if defined (SELECT_COMMAND)
+    struct select_com *Select;
+#endif
   } value;
 } COMMAND;
 
@@ -120,6 +148,18 @@ typedef struct for_com {
 			   members of MAP_LIST. */
 } FOR_COM;
 
+#if defined (SELECT_COMMAND)
+/* KSH SELECT command. */
+typedef struct select_com {
+  int flags;		/* See description of CMD flags. */
+  WORD_DESC *name;	/* The variable name to get mapped over. */
+  WORD_LIST *map_list;	/* The things to map over.  This is never NULL. */
+  COMMAND *action;	/* The action to execute.
+			   During execution, NAME is bound to the member of
+			   MAP_LIST chosen by the user. */
+} SELECT_COM;
+#endif /* SELECT_COMMAND */
+
 /* IF command. */
 typedef struct if_com {
   int flags;			/* See description of CMD flags. */
@@ -141,6 +181,7 @@ typedef struct simple_com {
   WORD_LIST *words;		/* The program name, the arguments,
 				   variable assignments, etc. */
   REDIRECT *redirects;		/* Redirections to perform. */
+  int line;			/* line number the command starts on */
 } SIMPLE_COM;
 
 /* The "function_def" command.  This isn't really a command, but it is
@@ -161,18 +202,14 @@ typedef struct group_com {
   COMMAND *command;
 } GROUP_COM;
 
-/* Forward declarations of functions called by the grammer. */
-extern REDIRECT *make_redirection ();
-extern WORD_LIST *make_word_list ();
-extern WORD_DESC *make_word ();
+extern COMMAND *global_command;
 
-extern COMMAND
-  *make_for_command (), *make_case_command (), *make_if_command (),
-  *make_while_command (), *command_connect (), *make_simple_command (),
-  *make_function_def (), *clean_simple_command (), *make_until_command (),
-  *make_group_command ();
+/* Forward declarations of functions declared in copy_cmd.c. */
 
-extern PATTERN_LIST *make_pattern_list ();
-extern COMMAND *global_command, *copy_command ();
+extern WORD_DESC *copy_word __P((WORD_DESC *));
+extern WORD_LIST *copy_word_list __P((WORD_LIST *));
+extern REDIRECT *copy_redirect __P((REDIRECT *));
+extern REDIRECT *copy_redirects __P((REDIRECT *));
+extern COMMAND *copy_command __P((COMMAND *));
 
 #endif /* _COMMAND_H */
